import styled from 'styled-components';

import defaultTheme from '../../theme';
import { HiroComponentProps } from '../../types';
import { flex, paddable } from '../../utils';

export interface FlexColumnProps extends HiroComponentProps {
  centered?: boolean;
  verticalAlign?: 'start' | 'center' | 'end';
  padded?: boolean;
  width?: number;
}

export const FlexColumn = styled.div<FlexColumnProps>(
  {
    flexFlow: 'column nowrap',
    height: '100%',
    padding: '0.5em',
  },
  flex(),
  paddable,
  ({ width }) => {
    if (!width) {
      return;
    }

    return {
      flex: `1 1 ${100 * width}%`,
    };
  },
);

FlexColumn.defaultProps = {
  theme: defaultTheme,
};

export interface FlexRowProps extends HiroComponentProps {
  centered?: boolean;
  verticalAlign?: 'start' | 'center' | 'end';
  padded?: boolean;
}

export const FlexRow = styled.div<FlexRowProps>(
  {
    flexFlow: 'row nowrap',
  },
  flex(true),
  paddable,
);

FlexRow.defaultProps = {
  theme: defaultTheme,
};
