import { themeGet } from '@styled-system/theme-get';
import { HiroColors } from './types';
import { CSSObject } from 'styled-components';

export const secondary = <
  T extends { color?: HiroColors; secondary?: boolean }
>(
  props: T,
) => {
  const value = themeGet(`colors.${props.color || 'primary'}.default`)(props);

  return (
    props.secondary && {
      border: `1px solid ${value}`,
      backgroundColor: 'transparent',
      color: value,
    }
  );
};

export const text = <T extends { color?: HiroColors }>(
  props: T,
): CSSObject | null =>
  props.color
    ? {
        color: themeGet(`colors.${props.color}.default`)(props),
      }
    : null;

export const paddable = <T extends { padded?: boolean }>(
  props: T,
): CSSObject | null =>
  props.padded
    ? {
        padding: '1rem 2.5rem',
      }
    : null;

export const flex = (isRow?: boolean) => <
  T extends { verticalAlign?: 'start' | 'center' | 'end'; centered?: boolean }
>({
  verticalAlign,
  centered,
}: T): CSSObject | null => {
  const s: Record<string, string | undefined> = {
    display: 'flex',
    justifyContent: undefined,
    alignItems: undefined,
  };

  if (verticalAlign) {
    s[isRow ? 'alignItems' : 'justifyContent'] = verticalAlign;
  }

  if (centered) {
    s[!isRow ? 'alignItems' : 'justifyContent'] = 'center';
  }

  return s;
};

export const colourable = <T extends { color?: HiroColors }>(
  props: T,
): CSSObject =>
  props.color
    ? {
        backgroundColor: themeGet(`colors.${props.color}.default`)(props),
        color: themeGet(`colors.${props.color}.text`)(props),
      }
    : {
        backgroundColor: themeGet(`colors.primary.default`)(props),
      };

export const clickable = <T extends { color?: string; disabled?: boolean }>(
  props: T,
): CSSObject => {
  return {
    cursor: 'pointer',

    // Disabled
    ...(props.disabled
      ? {
          pointerEvents: 'none' as const,
          opacity: 0.45,
        }
      : {}),

    // OnClick
    '&:active:hover': {
      backgroundColor: themeGet(`colors.${props.color || 'primary'}.active`)(
        props,
      ),
    },
    // Hover or focus
    '&:hover, &:focus': {
      backgroundColor: themeGet(`colors.${props.color || 'primary'}.hover`)(
        props,
      ),
    },
  };
};
